@@ -39,7 +39,11 @@ class RequestsExecutor(object):
             return certificate, None
         pfx = certificate["pfx"]
         password = certificate.get("password", None)
-        adapter = Pkcs12Adapter(pkcs12_data=pfx, pkcs12_password=password)
+        adapter = (
+            Pkcs12Adapter(pkcs12_filename=pfx, pkcs12_password=password)
+            if os.path.isfile(pfx)
+            else Pkcs12Adapter(pkcs12_data=pfx, pkcs12_password=password)
+        )
         return None, adapter
 
     def __init__(self, database_name, certificate, conventions=None, **kwargs):
@@ -52,7 +56,7 @@ class RequestsExecutor(object):
         self._last_known_urls = None
 
         self.headers = {"Accept": "application/json",
-                        "Raven-Client-Version": "5.0.0.1"}
+                        "Raven-Client-Version": "5.0.0.3"}
 
         self.update_topology_lock = Lock()
         self.update_timer_lock = Lock()
